pub struct Curve25519PolynomialRing(pub Polynomial<Curve25519FieldElement>);Tuple Fields
0: Polynomial<Curve25519FieldElement>Trait Implementations
Sourceimpl Add for Curve25519PolynomialRing
impl Add for Curve25519PolynomialRing
Sourceimpl AddAssign for Curve25519PolynomialRing
impl AddAssign for Curve25519PolynomialRing
Sourcefn add_assign(&mut self, other: Self)
fn add_assign(&mut self, other: Self)
Performs the
+= operation. Read moreSourceimpl Clone for Curve25519PolynomialRing
impl Clone for Curve25519PolynomialRing
Sourcefn clone(&self) -> Curve25519PolynomialRing
fn clone(&self) -> Curve25519PolynomialRing
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Curve25519PolynomialRing
impl Debug for Curve25519PolynomialRing
Sourceimpl Display for Curve25519PolynomialRing
impl Display for Curve25519PolynomialRing
Sourceimpl Div for Curve25519PolynomialRing
impl Div for Curve25519PolynomialRing
Sourceimpl FieldElement for Curve25519PolynomialRing
impl FieldElement for Curve25519PolynomialRing
Sourcefn from_usize(value: usize) -> Self
fn from_usize(value: usize) -> Self
Return a constant polynomial with the provided value
Sourcefn deserialize(str: &str) -> Self
fn deserialize(str: &str) -> Self
Parse an element from a supposedly
valid string representation.
Sourcefn to_biguint(&self) -> BigUint
fn to_biguint(&self) -> BigUint
Get a
num_bigint::BigUint representation for arbitrary
precision operations.Sourcefn from_biguint(_v: &BigUint) -> Self
fn from_biguint(_v: &BigUint) -> Self
Convert a
num_bigint::BigUint into a field element
precision operations. Numbers will be converted % self.prime()Sourcefn from_bytes_le(bytes: &[u8]) -> Self
fn from_bytes_le(bytes: &[u8]) -> Self
Parse an element from a byte representation. Panics
if the byte representation is too long. e.g. if the bytes
represent a value > Self::prime().
Sourcefn to_bytes_le(&self) -> Vec<u8> ⓘ
fn to_bytes_le(&self) -> Vec<u8> ⓘ
Convert a field element to a byte representation.
The number of bytes may be variable, but is guaranteed
to be accepted by
from_bytes_le for the same curve.Sourcefn sample_uniform<R>(src: &mut R) -> Selfwhere
R: Rng,
fn sample_uniform<R>(src: &mut R) -> Selfwhere
R: Rng,
Sample a random element from the field using a supplied
source of randomness. Requires the
random feature to be enabled.Sourcefn lower60_string(&self) -> String
fn lower60_string(&self) -> String
A string representation of a field element using
only the lower 60 bits of the element. A normal
decimal representation will be given if it’s shorter
than the lower 60 bit representation.
This is a lossy representation.
Sourcefn log_floor(&self, b: Self) -> u32
fn log_floor(&self, b: Self) -> u32
Take a logarithm using a custom base and return the
floored value.
O(logb(n)) time complexity where n
is the size of the element.Sourcefn legendre(&self) -> i32
fn legendre(&self) -> i32
Calculate the legendre symbol
for a field element. Used to determine if the
element is a quadratic residue.
Sourceimpl From<Polynomial<Curve25519FieldElement>> for Curve25519PolynomialRing
impl From<Polynomial<Curve25519FieldElement>> for Curve25519PolynomialRing
Sourcefn from(p: Polynomial<Curve25519FieldElement>) -> Self
fn from(p: Polynomial<Curve25519FieldElement>) -> Self
Converts to this type from the input type.
Sourceimpl From<u64> for Curve25519PolynomialRing
impl From<u64> for Curve25519PolynomialRing
Sourceimpl FromStr for Curve25519PolynomialRing
impl FromStr for Curve25519PolynomialRing
Sourceimpl Hash for Curve25519PolynomialRing
impl Hash for Curve25519PolynomialRing
Sourceimpl Mul for Curve25519PolynomialRing
impl Mul for Curve25519PolynomialRing
Sourceimpl MulAssign for Curve25519PolynomialRing
impl MulAssign for Curve25519PolynomialRing
Sourcefn mul_assign(&mut self, other: Self)
fn mul_assign(&mut self, other: Self)
Performs the
*= operation. Read moreSourceimpl Neg for Curve25519PolynomialRing
impl Neg for Curve25519PolynomialRing
Sourceimpl PartialEq for Curve25519PolynomialRing
impl PartialEq for Curve25519PolynomialRing
Sourceimpl PolynomialRingElement for Curve25519PolynomialRing
impl PolynomialRingElement for Curve25519PolynomialRing
type F = Curve25519FieldElement
Sourcefn modulus() -> Polynomial<Self::F>
fn modulus() -> Polynomial<Self::F>
Modulus used in remainder division to form
the polynomial ring. Read more
Sourcefn polynomial(&self) -> &Polynomial<Self::F>
fn polynomial(&self) -> &Polynomial<Self::F>
Return the Polynomial representation of the current value
Used to automatically implement norms and other functions.
Sourcefn from_polynomial(p: Polynomial<Self::F>) -> Self
fn from_polynomial(p: Polynomial<Self::F>) -> Self
Create a polynomial ring element from a Polynomial
with terms in the ring’s scalar field.
Sourcefn to_scalar(&self) -> Result<Self::F, Error>
fn to_scalar(&self) -> Result<Self::F, Error>
Attempt to get a scalar representation of the polynomial.
If the polynomial degree is > 0 this method will error.
Sourcefn norm_l1(&self) -> BigUint
fn norm_l1(&self) -> BigUint
Calculate the l1 norm for this polynomial. That is
the summation of all coefficients
Sourcefn norm_l2(&self) -> BigUint
fn norm_l2(&self) -> BigUint
Calculate the l2 norm for this polynomial. That is
the square root of the summation of each coefficient squared Read more
Sourcefn norm_max(&self) -> BigUint
fn norm_max(&self) -> BigUint
Calculate the l-infinity norm for this polynomial. That is
the largest coefficient
Sourceimpl Sub for Curve25519PolynomialRing
impl Sub for Curve25519PolynomialRing
Sourceimpl SubAssign for Curve25519PolynomialRing
impl SubAssign for Curve25519PolynomialRing
Sourcefn sub_assign(&mut self, other: Self)
fn sub_assign(&mut self, other: Self)
Performs the
-= operation. Read moreimpl Eq for Curve25519PolynomialRing
impl StructuralPartialEq for Curve25519PolynomialRing